@@ -26,6 +26,7 @@ from .test_archives import ArchiveTestCases
 class TestWriteReadTarFS(unittest.TestCase):
     def setUp(self):
         fh, self._temp_path = tempfile.mkstemp()
+        os.close(fh)
 
     def tearDown(self):
         os.remove(self._temp_path)
@@ -33,7 +34,7 @@ class TestWriteReadTarFS(unittest.TestCase):
     def test_unicode_paths(self):
         # https://github.com/PyFilesystem/pyfilesystem2/issues/135
         with tarfs.TarFS(self._temp_path, write=True) as tar_fs:
-            tar_fs.settext("Файл", "some content")
+            tar_fs.writetext("Файл", "some content")
 
         with tarfs.TarFS(self._temp_path) as tar_fs:
             paths = list(tar_fs.walk.files())
